==> pointpos_api-0.2.0.tar.gz: test/supplier_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Supplier
void main() {
  var instance = new Supplier();

  group('test Supplier', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String phoneNumber (default value: null)
    test('to test the property `phoneNumber`', () async {
      // TODO
    });

    // String email (default value: null)
    test('to test the property `email`', () async {
      // TODO
    });

    // String address (default value: null)
    test('to test the property `address`', () async {
      // TODO
    });

    // String city (default value: null)
    test('to test the property `city`', () async {
      // TODO
    });

    // String state (default value: null)
    test('to test the property `state`', () async {
      // TODO
    });

    // String zip (default value: null)
    test('to test the property `zip`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/supplier_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Supplier
void main() {
  var instance = new Supplier();

  group('test Supplier', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String phoneNumber (default value: null)
    test('to test the property `phoneNumber`', () async {
      // TODO
    });

    // String email (default value: null)
    test('to test the property `email`', () async {
      // TODO
    });

    // String address (default value: null)
    test('to test the property `address`', () async {
      // TODO
    });

    // String city (default value: null)
    test('to test the property `city`', () async {
      // TODO
    });

    // String state (default value: null)
    test('to test the property `state`', () async {
      // TODO
    });

    // String zip (default value: null)
    test('to test the property `zip`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
